UaePassAPI constructor
UaePassAPI({})
Constructs a new instance of the UaePassAPI class.
clientId: The client ID provided by UAE Pass.
redirectUri: The URI to which the user should be redirected after authentication.
clientSecrete: The client secret provided by UAE Pass.
appScheme: The scheme used by the Flutter application.
isProduction: Indicates whether the app is running in production mode.
language: Language parameter to be sent to render English or Arabic login pages of UAEPASS (English page : en Arabic page : ar).
Implementation
UaePassAPI( {
required String clientId,
required String redirectUri,
required String clientSecrete,
required String appScheme,
required bool isProduction,
String? language,
}) : _isProduction = isProduction,
_appScheme = appScheme,
_clientSecrete = clientSecrete,
_redirectUri = redirectUri,
_clientId = clientId,
_language = language;